==> idoit-1.10.zip: src/classes/modules/pro/lang/en.inc.php <==
<?php
/**
 * i-doit - Documentation and CMDB solution for IT environments
 *
 * This file is part of the i-doit framework. Modify at your own risk.
 *
 * Please visit http://www.i-doit.com/license for a full copyright and license information.
 *
 * @version     1.10
 * @package     i-doit
 * @author      synetics GmbH
 * @copyright   synetics GmbH
 * @url         http://www.i-doit.com
 * @license     http://www.i-doit.com/license
 */
/**
 * i-doit
 *
 * "Relocate-CI" Module language file
 *
 * @package     modules
 * @subpackage  relocate_ci
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.7
 */

return [
    'LC__LICENCE__TRIAL_INFO'                      => '30-day TRIAL VERSION until %s',
    'LC__LICENCE_OVERVIEW__CMDB_REFERENCES'        => 'CMDB references',
    'LC__LICENCE_OVERVIEW__CURRENT_VALUE'          => 'Current value',
    'LC__LICENCE_OVERVIEW__LICENCE_EXCEEDING'      => 'License exceeding',
    'LC__LICENCE_OVERVIEW__OBJECTCOUNT_BY_TYPE'    => 'Show object count by type',
    'LC__LICENCE_OVERVIEW__STATISTIC'              => 'Statistic',
    'LC__LICENCE__CHOOSE'                          => 'Choose license',
    'LC__LICENCE__CURRENTLY_NO_LICENCES'           => 'Currently there are no licenses installed',
    'LC__LICENCE__DELETED'                         => 'License successfully deleted.',
    'LC__LICENCE__DOCUMENTED_OBJECTS'              => 'Documented objects',
    'LC__LICENCE__ERROR_DB'                        => 'Your database name "%s" does not match the one in your licensing profile: "%s"',
    'LC__LICENCE__ERROR_KEY'                       => 'Your key is not correct. License installation aborted.',
    'LC__LICENCE__ERROR_OVERTIME'                  => 'Your license has expired. Please update your license on <a href="http://login.i-doit.com">login.i-doit.com</a> or contact <a href="mailto:sales@i-doit.com?subject=i-doit license renewal">sales@i-doit.com</a>.',
    'LC__LICENCE__ERROR_REG_DATE'                  => 'The registration date of your license is higher than the current date on your server!',
    'LC__LICENCE__FILE'                            => 'License file',
    'LC__LICENCE__FREE_OBJECTS'                    => 'Free objects',
    'LC__LICENCE__INSTALL'                         => 'Install license',
    'LC__LICENCE__INSTALLED_LICENCES'              => 'installed licenses',
    'LC__LICENCE__INSTALL_ERROR'                   => 'Error while installing license',
    'LC__LICENCE__INSTALL__FAIL'                   => 'Could not install license',
    'LC__LICENCE__INSTALL__FAIL_EXISTS'            => 'This license already exists',
    'LC__LICENCE__INSTALL__SUCCESSFULL'            => 'License was successfully installed and activated.',
    'LC__LICENCE__INSTALL__SUCCESSFULL__TO_EARLY'  => 'License was successfully installed, but will not be activated until %s.',
    'LC__LICENCE__LICENCED_DATABASE'               => 'Licensed database',
    'LC__LICENCE__LICENCE_TYPE'                    => 'License type',
    'LC__LICENCE__MAX_AMOUNT_OF_OBJECTS'           => 'Maximum amount of objects',
    'LC__LICENCE__NO_LICENCE'                      => 'Attention: Your i-doit is currently not licensed',
    'LC__LICENCE__NO_MODULE_LICENCE'               => 'Attention: Your "%s" module is currently not licensed',
    'LC__LICENCE__NO_UPLOAD'                       => 'No valid license file uploaded or your php-upload configration does not allow any uploads.',
    'LC__LICENCE__OBJECT_COUNTER'                  => 'Object counter by object type',
    'LC__LICENCE__OBJECT_COUNT_REACHED'            => 'The object limit of %s CMDB objects is reached by an amount of %s.',
    'LC__LICENCE__REACH_CONCLUSION'                => 'Your i-doit is not licensed anymore. Contact support@i-doit.com for further licensing.',
    'LC__LICENCE__REGISTRATION_DATE'               => 'Registration date',
    'LC__LICENCE__REMOVE'                          => 'Remove license',
    'LC__LICENCE__REMOVE_CONFIRMATION'             => 'Really remove license?\\n\\nThe license is only recoverable via re-installing it.',
    'LC__LICENCE__TYPE__SUBSCRIPTION'              => 'Subscription',
    'LC__LICENCE__UPGRADE__SUCCESSFULL'            => 'The upgrade of your existing license was successful.',
    'LC__LICENCE__UPGRADE__SUCCESSFULL__TO_EARLY'  => 'The upgrade of your existing license was successfull, but will not be activated until %s.',
    'LC__CATG__IMAGES'                             => 'Images',
    'LC__CATG__IMAGES__FILENAME'                   => 'Filename',
    'LC__CATG__IMAGES__FILECONTENT'                => 'Filecontent',
    'LC__CATG__IMAGES__DELETE_IMAGE_CONFIRM'       => 'Are you sure you want to permanently delete this image?',
    'LC__CATG__IMAGES__DELETE_IMAGE_ERROR'         => 'An error occured while deleting the image. Please try again!',
    'LC__CATG__IMAGES__UPLOAD_IMAGE_ERROR'         => 'An error occured while uploading the image. Please try again!',
    'LC__CATG__IMAGES__VIEW_BUTTON'                => 'Zoom image (Resolution: %s)',
    'LC__CATG__IMAGES__INFO__INNODB_LOG_FILE_SIZE' => 'Attention! The MySQL configuration "innodb_log_file_size" should be at least <code>32M</code> - currently it is %s MB.',
    'LC__CATG__STACK_PORT_OVERVIEW'                => 'Port Overview (Stacking)'
];

==> idoit-1.12.zip: src/classes/modules/pro/lang/en.inc.php <==
<?php
/**
 * i-doit
 *
 * "Relocate-CI" Module language file
 *
 * @package     modules
 * @subpackage  relocate_ci
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.0
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.7
 */

return [
    'LC__LICENCE__TRIAL_INFO'                      => '30-day TRIAL VERSION until %s',
    'LC__LICENCE_OVERVIEW__CMDB_REFERENCES'        => 'CMDB references',
    'LC__LICENCE_OVERVIEW__CURRENT_VALUE'          => 'Current value',
    'LC__LICENCE_OVERVIEW__LICENCE_EXCEEDING'      => 'License exceeding',
    'LC__LICENCE_OVERVIEW__OBJECTCOUNT_BY_TYPE'    => 'Show object count by type',
    'LC__LICENCE_OVERVIEW__STATISTIC'              => 'Statistic',
    'LC__LICENCE__CHOOSE'                          => 'Choose license',
    'LC__LICENCE__CURRENTLY_NO_LICENCES'           => 'Currently there are no licenses installed',
    'LC__LICENCE__DELETED'                         => 'License successfully deleted.',
    'LC__LICENCE__DOCUMENTED_OBJECTS'              => 'Documented objects',
    'LC__LICENCE__ERROR_DB'                        => 'Your database name "%s" does not match the one in your licensing profile: "%s"',
    'LC__LICENCE__ERROR_KEY'                       => 'Your key is not correct. License installation aborted.',
    'LC__LICENCE__ERROR_OVERTIME'                  => 'Your license has expired. Please update your license on <a href="http://login.i-doit.com">login.i-doit.com</a> or contact <a href="mailto:sales@i-doit.com?subject=i-doit license renewal">sales@i-doit.com</a>.',
    'LC__LICENCE__ERROR_REG_DATE'                  => 'The registration date of your license is higher than the current date on your server!',
    'LC__LICENCE__FILE'                            => 'License file',
    'LC__LICENCE__FREE_OBJECTS'                    => 'Free objects',
    'LC__LICENCE__INSTALL'                         => 'Install license',
    'LC__LICENCE__INSTALLED_LICENCES'              => 'installed licenses',
    'LC__LICENCE__INSTALL_ERROR'                   => 'Error while installing license',
    'LC__LICENCE__INSTALL__FAIL'                   => 'Could not install license',
    'LC__LICENCE__INSTALL__FAIL_EXISTS'            => 'This license already exists',
    'LC__LICENCE__INSTALL__SUCCESSFULL'            => 'License was successfully installed and activated.',
    'LC__LICENCE__INSTALL__SUCCESSFULL__TO_EARLY'  => 'License was successfully installed, but will not be activated until %s.',
    'LC__LICENCE__LICENCED_DATABASE'               => 'Licensed database',
    'LC__LICENCE__LICENCE_TYPE'                    => 'License type',
    'LC__LICENCE__MAX_AMOUNT_OF_OBJECTS'           => 'Maximum amount of objects',
    'LC__LICENCE__NO_LICENCE'                      => 'Attention: Your i-doit is currently not licensed',
    'LC__LICENCE__NO_MODULE_LICENCE'               => 'Attention: Your "%s" module is currently not licensed',
    'LC__LICENCE__NO_UPLOAD'                       => 'No valid license file uploaded or your php-upload configration does not allow any uploads.',
    'LC__LICENCE__OBJECT_COUNTER'                  => 'Object counter by object type',
    'LC__LICENCE__OBJECT_COUNT_REACHED'            => 'The object limit of %s CMDB objects is reached by an amount of %s.',
    'LC__LICENCE__REACH_CONCLUSION'                => 'Your i-doit is not licensed anymore. Contact support@i-doit.com for further licensing.',
    'LC__LICENCE__REGISTRATION_DATE'               => 'Registration date',
    'LC__LICENCE__REMOVE'                          => 'Remove license',
    'LC__LICENCE__REMOVE_CONFIRMATION'             => 'Really remove license?\\n\\nThe license is only recoverable via re-installing it.',
    'LC__LICENCE__TYPE__SUBSCRIPTION'              => 'Subscription',
    'LC__LICENCE__UPGRADE__SUCCESSFULL'            => 'The upgrade of your existing license was successful.',
    'LC__LICENCE__UPGRADE__SUCCESSFULL__TO_EARLY'  => 'The upgrade of your existing license was successfull, but will not be activated until %s.',
    'LC__CATG__IMAGES'                             => 'Images',
    'LC__CATG__IMAGES__FILENAME'                   => 'Filename',
    'LC__CATG__IMAGES__FILECONTENT'                => 'Filecontent',
    'LC__CATG__IMAGES__DELETE_IMAGE_CONFIRM'       => 'Are you sure you want to permanently delete this image?',
    'LC__CATG__IMAGES__DELETE_IMAGE_ERROR'         => 'An error occured while deleting the image. Please try again!',
    'LC__CATG__IMAGES__UPLOAD_IMAGE_ERROR'         => 'An error occured while uploading the image. Please try again!',
    'LC__CATG__IMAGES__VIEW_BUTTON'                => 'Zoom image (Resolution: %s)',
    'LC__CATG__IMAGES__INFO__INNODB_LOG_FILE_SIZE' => 'Attention! The MySQL configuration "innodb_log_file_size" should be at least <code>32M</code> - currently it is %s MB.',
    'LC__CATG__IMAGES__ORDER_IMAGES'               => 'Order images',
    'LC__CATG__IMAGES__SAVE_ORDER'                 => 'Save images order',
    'LC__CATG__STACK_PORT_OVERVIEW'                => 'Port Overview (Stacking)'
];
